function log = glucose_control_I(saveFig, savePath, figName)

% G, X, I, t, tl
%set options---------------------------------------------------------------
options.x0 = interval([13;0;0.5;0;0],[14;0;0.5;0;0]);
options.R0 = zonotope(options.x0);
options.taylorTerms = 10;
options.zonotopeOrder = 20;
options.polytopeOrder = 10;
options.reductionTechnique = 'girard';
options.isHyperplaneMap = 0;
options.guardIntersect = 'polytope';
options.enclosureEnables = 5;
options.originContained = 0;
options.maxError = 2 * ones(5,1);
options.verbose = 1;
options.tensorOrder = 1;
options.advancedLinErrorComp = 0;
options.reductionInterval = inf;
options.startLoc = 3;
options.finalLoc = 0;
options.tStart = 0;
options.tFinal = 720;


%define flows--------------------------------------------------------------

flow1 = nonlinearSys(5, 1, @glucose_control_I_FlowEq_1, options);
flow2 = nonlinearSys(5, 1, @glucose_control_I_FlowEq_2, options);
flow3 = nonlinearSys(5, 1, @glucose_control_I_FlowEq_3, options);

%define invariants---------------------------------------------------------

% G <= 4 t <= 720
inv_l1 =  mptPolytope(struct('A', [1 0 0 0 0 ; 0 0 0 1 0], 'b', [ 4;  720]));
% 4 <= G <= 8 t <= 720
inv_l2 =  mptPolytope(struct('A', [-1 0 0 0 0 ; 1 0 0 0 0 ; 0 0 0 1 0 ], 'b', [-4;  8;  720]));
% G >= 8 t <= 720
inv_l3 =  mptPolytope(struct('A', [-1 0 0 0 0 ; 0 0 0 1 0 ], 'b', [-8;  720]));

%define transitions--------------------------------------------------------

%  l1 -> l2
% G = 4 tl >= 0.2 
guard =  mptPolytope(struct('A', [-1 0 0 0 0; 1 0 0 0 0; 0 0 0 0 -1], 'b', [-4;4;-0.2]));
%    tl := 0 
reset.A = [1 0 0 0 0 ; 0 1 0 0 0 ; 0 0 1 0 0 ; 0 0 0 1 0 ; 0 0 0 0 0 ];
reset.b = [0; 0; 0; 0; 0];
trans_l1{1} = transition(guard, reset, 2, 'l1', 'l2');

%  l2 -> l1
% G = 4 tl >= 0.2 
guard =  mptPolytope(struct('A', [-1 0 0 0 0; 1 0 0 0 0; 0 0 0 0 -1], 'b', [-4;4;-0.2]));
%    tl := 0 
reset.A = [1 0 0 0 0 ; 0 1 0 0 0 ; 0 0 1 0 0 ; 0 0 0 1 0 ; 0 0 0 0 0 ];
reset.b = [0; 0; 0; 0; 0];
trans_l2{1} = transition(guard, reset, 1, 'l2', 'l1');

%  l2 -> l3
% G = 8 tl >= 0.2 
guard =  mptPolytope(struct('A', [-1 0 0 0 0; 1 0 0 0 0; 0 0 0 0 -1], 'b', [-8;8;-0.2]));
%    tl := 0 
reset.A = [1 0 0 0 0 ; 0 1 0 0 0 ; 0 0 1 0 0 ; 0 0 0 1 0 ; 0 0 0 0 0 ];
reset.b = [0; 0; 0; 0; 0];
trans_l2{2} = transition(guard, reset, 3, 'l2', 'l3');

%  l3 -> l2
% G = 8 tl >= 0.2 
guard =  mptPolytope(struct('A', [-1 0 0 0 0; 1 0 0 0 0; 0 0 0 0 -1], 'b', [-8;8;-0.2]));
%    tl := 0 
reset.A = [1 0 0 0 0 ; 0 1 0 0 0 ; 0 0 1 0 0 ; 0 0 0 1 0 ; 0 0 0 0 0 ];
reset.b = [0; 0; 0; 0; 0];
trans_l3{1} = transition(guard, reset, 2, 'l3', 'l2');

%define locations----------------------------------------------------------

for i = 1:3
    options.uLoc{i} = 0;
    options.uLocTrans{i} = 0;
    options.Uloc{i} = zonotope(0);
    options.timeStepLoc{i}= 0.01;
end


loc{1} = location('l1', 1, inv_l1, trans_l1, flow1);
loc{2} = location('l2', 2, inv_l2, trans_l2, flow2);
loc{3} = location('l3', 3, inv_l3, trans_l3, flow3);

%define hybrid automaton---------------------------------------------------

HA = hybridAutomaton(loc);
tic;
[HA] = reach(HA, options);
reachabilityT = toc;

verificationT = 0;
safe = 0;
time = reachabilityT + verificationT;
log = [figName, ' ', num2str(reachabilityT), ' ', num2str(verificationT), ' ', num2str(time), ' ', num2str(safe)];


fig = figure();
hold on
options.projectedDimensions = [4 1];
options.plotType = 'b';
plot(HA,'reachableSet',options); %plot reachable set
plotFilled(options.R0,options.projectedDimensions,'w','EdgeColor','k'); %plot initial set

if saveFig
    fname = strcat(figName,'.','png');
    saveas(fig, fullfile(savePath,fname),'png');
end
end
